@@ -1,4 +1,4 @@
-//$Id: radar.cc,v 1.6 2003/03/14 23:39:14 murrayc Exp $ -*- c++ -*-
+//$Id: radar.cc,v 1.4 2004/03/28 18:58:01 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -93,7 +93,7 @@ PPI::PPI()
   colormap->alloc_color(yellow_);
 
   // timeout
-  Glib::signal_timeout().connect(SigC::slot(*this, &PPI::timer_callback), 50);
+  Glib::signal_timeout().connect(sigc::mem_fun(*this, &PPI::timer_callback), 50);
 
   // loop, alpha
   loop = 0;
@@ -206,22 +206,20 @@ bool PPI::on_expose_event(GdkEventExpose*)
 
   // "RADAR DEMO!" text
    gc_->set_foreground(white_);  
-   Glib::ustring us1("RADAR");
-   Glib::ustring us2(" DEMO!");
+   Glib::ustring us1 = "RADAR";
+   Glib::ustring us2 = " DEMO!";
    Glib::ustring us3 = us1 + us2;
    Glib::RefPtr<Pango::Layout> pl1 = create_pango_layout(us3);
-   
-     // TODO: FontDescription   
-     Pango::FontDescription fd;
-     fd.set_size(1000);
-     pl1->set_font_description(/* const FontDescription& desc */ fd);
-     // TODO END
+     
+   Pango::FontDescription fd;
+   fd.set_size(1000);
+   pl1->set_font_description(/* const FontDescription& desc */ fd);
 
-     window->draw_layout(gc_, 0, 0, pl1);
+   window->draw_layout(gc_, 0, 0, pl1);
 
   // "Loop = " text
    gc_->set_foreground(white_);  
-   Glib::ustring us4("Loop=");
+   Glib::ustring us4 = "Loop=";
  
    // 21.5.3 TCPL 3eme ed. 
    std::ostringstream ost;
@@ -306,6 +304,9 @@ public:
   virtual ~Radar();
   
 protected:
+  //signal handlers:
+  void on_button2_clicked();
+  
   // Child widgets
   Gtk::VBox m_box0;
   Gtk::HBox m_box1;
@@ -327,7 +328,7 @@ Radar::Radar()
 {
 
   // box2
-  m_button2.signal_clicked().connect(SigC::slot(*this, &Gtk::Widget::hide));
+  m_button2.signal_clicked().connect(sigc::mem_fun(*this, &Radar::on_button2_clicked));
   m_box2.pack_start(m_box3, /*Gtk::PackOptions*/Gtk::PACK_EXPAND_WIDGET, /*padding*/5);
   m_box2.pack_start(m_button1, Gtk::PACK_SHRINK, 5);
   m_box2.pack_start(m_button2, Gtk::PACK_SHRINK, 5);
@@ -352,6 +353,11 @@ Radar::~Radar()
 {
 }
 
+void Radar::on_button2_clicked()
+{
+  hide();
+}
+
 
 int main(int argc, char** argv)
 {
